@@ -118,6 +118,13 @@ void Flotsam::Move(vector<Visual> &visuals)
 
 
 
+void Flotsam::SetVelocity(Point velocity)
+{
+	this->velocity = velocity;
+}
+
+
+
 // This is the one ship that cannot pick up this flotsam.
 const Ship *Flotsam::Source() const
 {
@@ -166,6 +173,13 @@ double Flotsam::UnitSize() const
 
 
 
+double Flotsam::Mass() const
+{
+	return Count() * UnitSize();
+}
+
+
+
 // Transfer contents to the collector ship. The flotsam velocity is
 // stabilized in proportion to the amount being transferred.
 int Flotsam::TransferTo(Ship *collector)
