@@ -44,10 +44,12 @@ namespace {
 
 
 // Constructor.
-Hardpoint::Hardpoint(const Point &point, const Angle &baseAngle, bool isTurret,
-	bool isParallel, bool isUnder, const Outfit *outfit)
-	: outfit(outfit), point(point * .5), baseAngle(baseAngle), isTurret(isTurret), isParallel(isParallel), isUnder(isUnder)
+Hardpoint::Hardpoint(const Point &point, const BaseAttributes &attributes,
+	bool isTurret, bool isUnder, const Outfit *outfit)
+	: outfit(outfit), point(point * .5), baseAngle(attributes.baseAngle), baseAttributes(attributes),
+	isTurret(isTurret), isParallel(baseAttributes.isParallel), isUnder(isUnder)
 {
+	UpdateArc();
 }
 
 
@@ -77,14 +79,31 @@ const Angle &Hardpoint::GetAngle() const
 
 
 
-// Get the default facing direction for a gun
-const Angle &Hardpoint::GetBaseAngle() const
+// Get the angle of a turret when idling, relative to the ship.
+// For guns, this function is equal to GetAngle().
+const Angle &Hardpoint::GetIdleAngle() const
 {
 	return baseAngle;
 }
 
 
 
+// Get the arc of fire if this is a directional turret,
+// otherwise a pair of 180 degree + baseAngle.
+const Angle &Hardpoint::GetMinArc() const
+{
+	return minArc;
+}
+
+
+
+const Angle &Hardpoint::GetMaxArc() const
+{
+	return maxArc;
+}
+
+
+
 // Get the angle this weapon ought to point at for ideal gun harmonization.
 Angle Hardpoint::HarmonizedAngle() const
 {
@@ -114,7 +133,6 @@ bool Hardpoint::IsTurret() const
 
 
 
-
 bool Hardpoint::IsParallel() const
 {
 	return isParallel;
@@ -122,6 +140,13 @@ bool Hardpoint::IsParallel() const
 
 
 
+bool Hardpoint::IsOmnidirectional() const
+{
+	return isOmnidirectional;
+}
+
+
+
 bool Hardpoint::IsUnder() const
 {
 	return isUnder;
@@ -201,13 +226,25 @@ void Hardpoint::Step()
 
 
 // Adjust this weapon's aim by the given amount, relative to its maximum
-// "turret turn" rate.
+// "turret turn" rate. Up to its angle limit.
 void Hardpoint::Aim(double amount)
 {
 	if(!outfit)
 		return;
 
-	angle += outfit->TurretTurn() * amount;
+	const double add = outfit->TurretTurn() * amount;
+	if(isOmnidirectional)
+		angle += add;
+	else
+	{
+		const Angle newAngle = angle + add;
+		if(add < 0. && minArc.IsInRange(newAngle, angle))
+			angle = minArc;
+		else if(add > 0. && maxArc.IsInRange(angle, newAngle))
+			angle = maxArc;
+		else
+			angle += add;
+	}
 }
 
 
@@ -306,20 +343,23 @@ void Hardpoint::Install(const Outfit *outfit)
 		this->outfit = outfit;
 		Reload();
 
-		// For fixed weapons, apply "gun harmonization," pointing them slightly
-		// inward so the projectiles will converge. For turrets, start them out
-		// pointing outward from the center of the ship.
-		if(!isTurret)
+		// Update the arc of fire because of changing an outfit.
+		UpdateArc();
+
+		// For fixed weapons and idling turrets, apply "gun harmonization,"
+		// pointing them slightly inward so the projectiles will converge.
+		// Weapons that fire parallel beams don't get a harmonized angle.
+		// And some hardpoints/gunslots are configured not to get harmonized.
+		// So only harmonize when both the port and the outfit supports it.
+		if(!isParallel && !outfit->IsParallel())
 		{
-			angle = baseAngle;
-			// Weapons that fire in parallel beams don't get a harmonized angle.
-			// And some hardpoints/gunslots are configured not to get harmonized.
-			// So only harmonize when both the port and the outfit supports it.
-			if(!isParallel && !outfit->IsParallel())
-				angle += HarmonizedAngle();
+			const Angle harmonized = baseAngle + HarmonizedAngle();
+			// The harmonized angle might be out of the arc of a turret.
+			// If so, this turret is forced "parallel."
+			if(!isTurret || isOmnidirectional || harmonized.IsInRange(GetMinArc(), GetMaxArc()))
+				baseAngle = harmonized;
 		}
-		else
-			angle = Angle(point);
+		angle = baseAngle;
 	}
 }
 
@@ -339,6 +379,17 @@ void Hardpoint::Reload()
 void Hardpoint::Uninstall()
 {
 	outfit = nullptr;
+
+	// Update the arc of fire because of changing an outfit.
+	UpdateArc();
+}
+
+
+
+// Get the attributes that can be used as a parameter of the constructor when cloning this.
+const Hardpoint::BaseAttributes &Hardpoint::GetBaseAttributes() const
+{
+	return baseAttributes;
 }
 
 
@@ -350,20 +401,29 @@ bool Hardpoint::FireSpecialSystem(Ship &ship, const Body &body, std::vector<Visu
 	// Get the weapon range. Anti-missile and tractor beam shots always last a
 	// single frame, so their range is equal to their velocity.
 	double range = outfit->Velocity();
+	Angle facing = ship.Facing();
 
 	// Check if the body is within range of this hardpoint.
-	Point start = ship.Position() + ship.Facing().Rotate(point);
+	Point start = ship.Position() + facing.Rotate(point);
 	Point offset = body.Position() - start;
 	if(offset.Length() > range)
 		return false;
 
+	// Check if the target is within the arc of fire.
+	Angle aim(offset);
+	if(!isOmnidirectional)
+	{
+		const Angle minArc = GetMinArc() + facing;
+		const Angle maxArc = GetMaxArc() + facing;
+		if(!aim.IsInRange(minArc, maxArc))
+			return false;
+	}
+
 	// Precompute the number of visuals that will be added.
 	visuals.reserve(visuals.size() + outfit->FireEffects().size()
 		+ outfit->HitEffects().size() + outfit->DieEffects().size());
 
-	// Firing effects are displayed at the weapon hardpoint that just fired.
-	Angle aim(offset);
-	angle = aim - ship.Facing();
+	angle = aim - facing;
 	start += aim.Rotate(outfit->HardpointOffset());
 	CreateEffects(outfit->FireEffects(), start, ship.Velocity(), aim, visuals);
 
@@ -407,3 +467,53 @@ void Hardpoint::Fire(Ship &ship, const Point &start, const Angle &aim)
 	// case the outfit is its own ammunition.
 	ship.ExpendAmmo(*outfit);
 }
+
+
+
+// The arc depends on both the base hardpoint and the installed outfit.
+void Hardpoint::UpdateArc()
+{
+	if(!outfit)
+		return;
+
+	// Restore the initial value (from baseAttributes).
+	isOmnidirectional = baseAttributes.isOmnidirectional;
+	baseAngle = baseAttributes.baseAngle;
+	if(isOmnidirectional)
+	{
+		const Angle opposite = baseAngle + Angle(180.);
+		minArc = opposite;
+		maxArc = opposite;
+	}
+	else
+	{
+		minArc = baseAttributes.minArc;
+		maxArc = baseAttributes.maxArc;
+	}
+
+	// The installed weapon restricts the arc of fire.
+	const double hardpointsArc = (maxArc - minArc).AbsDegrees();
+	const double weaponsArc = outfit->Arc();
+	if(weaponsArc < 360. && (isOmnidirectional || weaponsArc < hardpointsArc))
+	{
+		isOmnidirectional = false;
+		const double weaponsHalf = weaponsArc / 2.;
+
+		// The base angle is placed as close to center as possible.
+		const Angle &firstAngle = minArc;
+		const Angle &secondAngle = maxArc;
+		double hardpointsMinArc = (baseAngle - firstAngle).AbsDegrees();
+		double hardpointsMaxArc = (secondAngle - baseAngle).AbsDegrees();
+		if(hardpointsMinArc < weaponsHalf)
+			hardpointsMaxArc = weaponsArc - hardpointsMinArc;
+		else if(hardpointsMaxArc < weaponsHalf)
+			hardpointsMinArc = weaponsArc - hardpointsMaxArc;
+		else
+		{
+			hardpointsMinArc = weaponsHalf;
+			hardpointsMaxArc = weaponsHalf;
+		}
+		minArc = baseAngle - hardpointsMinArc;
+		maxArc = baseAngle + hardpointsMaxArc;
+	}
+}
